@@ -11,7 +11,6 @@
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
 import os
-import subprocess
 import sys
 from datetime import date
 
@@ -21,8 +20,8 @@ from datetime import date
 # -- Project information -----------------------------------------------------
 
 project = "DPDispatcher"
-copyright = "2020-%d, Deep Modeling" % date.today().year
-author = "Deep Modeling"
+copyright = f"2020-{date.today().year}, Deep Modeling"
+author = "DeepModeling"
 
 
 # -- General configuration ---------------------------------------------------
@@ -34,11 +33,12 @@ extensions = [
     "deepmodeling_sphinx",
     "dargs.sphinx",
     "myst_parser",
-    "sphinx_rtd_theme",
+    "sphinx_book_theme",
     "sphinx.ext.viewcode",
     "sphinx.ext.intersphinx",
     "numpydoc",
     "sphinx.ext.autosummary",
+    "sphinxarg.ext",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -55,7 +55,7 @@ exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = "sphinx_rtd_theme"
+html_theme = "sphinx_book_theme"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -97,3 +97,7 @@ intersphinx_mapping = {
     "python": ("https://docs.python.org/", None),
     "dargs": ("https://docs.deepmodeling.com/projects/dargs/en/latest/", None),
 }
+
+myst_enable_extensions = [
+    "colon_fence",
+]
