@@ -3,12 +3,10 @@ import os
 import sys
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
-from dpdispatcher.dp_cloud_server import DpCloudServer
-from dpdispatcher.dp_cloud_server_context import DpCloudServerContext
 
 # from dpdispatcher.batch_object import BatchObject
 from dpdispatcher.machine import Machine
-from dpdispatcher.submission import Job, Resources, Submission, Task
+from dpdispatcher.submission import Resources, Submission, Task
 
 # from dpdispatcher.slurm import SlurmResources, Slurm
 
@@ -36,7 +34,7 @@ from dpdispatcher.submission import Job, Resources, Submission, Task
 # dp_cloud_server = DpCloudServer(context=dp_cloud_server_context)
 # with open('test_dp_cloud_server.json', 'r') as f:
 #     jdata = json.load(f)
-with open("jsons/machine_dp_cloud_server.json", "r") as f:
+with open("jsons/machine_dp_cloud_server.json") as f:
     compute_dict = json.load(f)
 
 machine = Machine.load_from_dict(compute_dict["machine"])
