@@ -1,19 +1,12 @@
 #!/usr/bin/env python3
-import glob
 import json
 import os
-import shutil
 import sys
-import time
-import unittest
-import uuid
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 __package__ = "tests"
 # from .context import LocalContext
-from dpdispatcher.local_context import LocalContext
 
-from .context import Job, JobStatus, Resources, Submission, Task
 from .sample_class import SampleClass
 
 task_dict = SampleClass.get_sample_task_dict()
