@@ -1,25 +1,15 @@
-import glob
-import json
 import os
-import shutil
 import sys
-import time
 import unittest
-import uuid
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 __package__ = "tests"
 # from .context import LocalSession
 # from .context import LocalContext
 from .context import (
-    PBS,
     Job,
-    JobStatus,
-    LocalContext,
-    Resources,
     Submission,
-    Task,
-    setUpModule,
+    setUpModule,  # noqa: F401
 )
 from .sample_class import SampleClass
 
