@@ -1,35 +1,26 @@
-import glob
-import json
 import os
-import shutil
 import sys
-import time
 import unittest
-import uuid
 from socket import gaierror
-from unittest.mock import MagicMock, PropertyMock, patch
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 __package__ = "tests"
 from dargs.dargs import ArgumentValueError
 
-from .context import (
+from .context import (  # noqa: F401
     LSF,
     PBS,
     BaseContext,
     DistributedShell,
-    HDFSContext,
-    JobStatus,
+    JH_UniScheduler,
     LazyLocalContext,
     Lebesgue,
     LocalContext,
     Machine,
     Shell,
     Slurm,
-    SSHContext,
-    dargs,
+    setUpModule,
 )
-from .sample_class import SampleClass
 
 
 class TestMachineDispatch(unittest.TestCase):
@@ -164,6 +155,15 @@ class TestMachineDispatch(unittest.TestCase):
         machine = Machine.load_from_dict(machine_dict=machine_dict)
         self.assertIsInstance(machine, Slurm)
 
+    def test_jh_unischeduler(self):
+        machine_dict = {
+            "batch_type": "JH_UniScheduler",
+            "context_type": "LazyLocalContext",
+            "local_root": "./",
+        }
+        machine = Machine.load_from_dict(machine_dict=machine_dict)
+        self.assertIsInstance(machine, JH_UniScheduler)
+
     def test_shell(self):
         machine_dict = {
             "batch_type": "Shell",
