@@ -1,25 +1,15 @@
-import glob
 import json
 import os
-import shutil
 import sys
-import time
 import unittest
-import uuid
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 __package__ = "tests"
 # from .context import LocalSession
 # from .context import LocalContext
 from .context import (
-    PBS,
-    Job,
-    JobStatus,
-    LocalContext,
     Resources,
-    Submission,
-    Task,
-    setUpModule,
+    setUpModule,  # noqa: F401
 )
 from .sample_class import SampleClass
 
@@ -47,11 +37,14 @@ class TestResources(unittest.TestCase):
         )
 
     def test_resources_json(self):
-        with open("jsons/resources.json", "r") as f:
+        with open("jsons/resources.json") as f:
             resources_json_dict = json.load(f)
         self.assertTrue(resources_json_dict, self.resources_dict)
         self.assertTrue(resources_json_dict, self.resources.serialize())
 
+    def test_arginfo(self):
+        self.resources.arginfo()
+
     def test_load_from_json(self):
         resources = Resources.load_from_json("jsons/resources.json")
         self.assertTrue(resources, self.resources)
