@@ -1,19 +1,17 @@
-import glob
 import json
 import os
-import shutil
 import sys
-import time
 import unittest
-import uuid
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 __package__ = "tests"
 # from .context import LocalContext
-from dpdispatcher.local_context import LocalContext
 
 # from .context import Dispatcher
-from .context import Job, JobStatus, Resources, Submission, Task, setUpModule
+from .context import (
+    Task,
+    setUpModule,  # noqa: F401
+)
 from .sample_class import SampleClass
 
 
@@ -33,7 +31,7 @@ class TestTask(unittest.TestCase):
         self.assertEqual(Task.deserialize(task_dict=self.task.serialize()), self.task)
 
     def test_task_json(self):
-        with open("jsons/task.json", "r") as f:
+        with open("jsons/task.json") as f:
             task_json_dict = json.load(f)
         self.assertTrue(task_json_dict, self.task_dict)
         self.assertTrue(task_json_dict, self.task.serialize())
