@@ -1,15 +1,13 @@
-import glob
-import json
 import os
-import shutil
 import sys
-import time
 import unittest
-import uuid
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 __package__ = "tests"
-from .context import dpdispatcher
+from .context import (
+    dpdispatcher,
+    setUpModule,  # noqa: F401
+)
 
 
 class TestImportClasses(unittest.TestCase):
