@@ -1,8 +1,8 @@
 # from dpdispatcher.batch_object import BatchObject
 # from dpdispatcher.batch import Batch
 import os
-import shutil
 import sys
+import tempfile
 import textwrap
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
@@ -11,14 +11,11 @@ import json
 import unittest
 
 from .context import (
-    Job,
-    LocalContext,
     Machine,
     Resources,
-    Shell,
     Submission,
     Task,
-    get_file_md5,
+    setUpModule,  # noqa: F401
 )
 
 
@@ -27,7 +24,7 @@ class TestLSFScriptGeneration(unittest.TestCase):
         self.maxDiff = None
 
     def test_shell_trival(self):
-        with open("jsons/machine_lazy_local_lsf.json", "r") as f:
+        with open("jsons/machine_lazy_local_lsf.json") as f:
             machine_dict = json.load(f)
 
         machine = Machine(**machine_dict["machine"])
@@ -101,7 +98,7 @@ class TestLSFScriptGeneration(unittest.TestCase):
 
         env_str = machine.gen_script_env(test_job)
         benchmark_env = textwrap.dedent(
-            """
+            f"""
             REMOTE_ROOT={task_hash}
             echo 0 > $REMOTE_ROOT/{job_hash}_flag_if_job_task_fail
             test $? -ne 0 && exit 1
@@ -111,15 +108,18 @@ class TestLSFScriptGeneration(unittest.TestCase):
             module load use.own
             module load deepmd/1.3
 
-            {{ source /data/home/ypliu/scripts/avail_gpu.sh; }} 
-            {{ source /data/home/ypliu/dprun/tf_envs.sh; }} 
+            source /data/home/ypliu/scripts/avail_gpu.sh
+            source /data/home/ypliu/dprun/tf_envs.sh
 
+            export DPDISPATCHER_NUMBER_NODE=1
+            export DPDISPATCHER_CPU_PER_NODE=4
+            export DPDISPATCHER_GPU_PER_NODE=1
+            export DPDISPATCHER_QUEUE_NAME=gpu
+            export DPDISPATCHER_GROUP_SIZE=4
             export DP_DISPATCHER_EXPORT=test_foo_bar_baz
 
             echo 'The summer you were there.'
-            """.format(
-                task_hash=task_hash, job_hash=job_hash
-            )
+            """
         )
         self.assertEqual(env_str.split("\n")[2:], benchmark_env.split("\n")[2:])
 
@@ -139,3 +139,72 @@ class TestLSFScriptGeneration(unittest.TestCase):
             """
         )
         self.assertEqual(footer_str, benchmark_footer)
+
+    @unittest.skipIf(sys.platform == "win32", "skip for persimission error")
+    def test_template(self):
+        with open("jsons/machine_lazy_local_lsf.json") as f:
+            machine_dict = json.load(f)
+
+        benchmark_str = textwrap.dedent(
+            """\
+            #!/bin/bash -l
+            #BSUB -e %J.err
+            #BSUB -o %J.out
+            #BSUB -n 4
+            #BSUB -R 'span[ptile=4]'
+            #BSUB -q gpu
+            #BSUB -gpu 'num=1:mode=shared:j_exclusive=no'"""
+        )
+
+        with tempfile.NamedTemporaryFile("w") as f:
+            f.write(benchmark_str)
+            f.flush()
+
+            machine_dict["resources"]["strategy"][
+                "customized_script_header_template_file"
+            ] = f.name
+
+            machine = Machine(**machine_dict["machine"])
+            resources = Resources(**machine_dict["resources"])
+
+            task1 = Task(
+                command="cat example.txt",
+                task_work_path="dir1/",
+                forward_files=["example.txt"],
+                backward_files=["out.txt"],
+                outlog="out.txt",
+            )
+            task2 = Task(
+                command="cat example.txt",
+                task_work_path="dir2/",
+                forward_files=["example.txt"],
+                backward_files=["out.txt"],
+                outlog="out.txt",
+            )
+            task3 = Task(
+                command="cat example.txt",
+                task_work_path="dir3/",
+                forward_files=["example.txt"],
+                backward_files=["out.txt"],
+                outlog="out.txt",
+            )
+            task4 = Task(
+                command="cat example.txt",
+                task_work_path="dir4/",
+                forward_files=["example.txt"],
+                backward_files=["out.txt"],
+                outlog="out.txt",
+            )
+            task_list = [task1, task2, task3, task4]
+
+            submission = Submission(
+                work_base="parent_dir/",
+                machine=machine,
+                resources=resources,
+                forward_common_files=["graph.pb"],
+                backward_common_files=[],
+                task_list=task_list,
+            )
+            submission.generate_jobs()
+            str = machine.gen_script_header(submission.belonging_jobs[0])
+            self.assertEqual(str, benchmark_str)
